==> wpewebkit_2.34.2.orig.tar.xz: wpewebkit-2.34.2/Source/WebCore/Modules/applepay/ApplePayCouponCodeChangedEvent.h <==
/*
 * Copyright (C) 2021 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#if ENABLE(APPLE_PAY_COUPON_CODE)

#include "Event.h"
#include <wtf/text/WTFString.h>

namespace WebCore {

class ApplePayCouponCodeChangedEvent final : public Event {
    WTF_MAKE_ISO_ALLOCATED(ApplePayCouponCodeChangedEvent);
public:
    static Ref<ApplePayCouponCodeChangedEvent> create(const AtomString& type, String&& couponCode)
    {
        return adoptRef(*new ApplePayCouponCodeChangedEvent(type, WTFMove(couponCode)));
    }

    virtual ~ApplePayCouponCodeChangedEvent();

    const String& couponCode() const { return m_couponCode; }

private:
    ApplePayCouponCodeChangedEvent(const AtomString& type, String&&);

    // Event
    EventInterface eventInterface() const override;

    const String m_couponCode;
};

} // namespace WebCore

#endif // ENABLE(APPLE_PAY_COUPON_CODE)

==> wpewebkit_2.46.5.orig.tar.xz: wpewebkit-2.46.5/Source/WebCore/Modules/applepay/ApplePayCouponCodeChangedEvent.h <==
/*
 * Copyright (C) 2021 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#if ENABLE(APPLE_PAY_COUPON_CODE)

#include "Event.h"
#include <wtf/text/WTFString.h>

namespace WebCore {

class ApplePayCouponCodeChangedEvent final : public Event {
    WTF_MAKE_TZONE_OR_ISO_ALLOCATED(ApplePayCouponCodeChangedEvent);
public:
    static Ref<ApplePayCouponCodeChangedEvent> create(const AtomString& type, String&& couponCode)
    {
        return adoptRef(*new ApplePayCouponCodeChangedEvent(type, WTFMove(couponCode)));
    }

    virtual ~ApplePayCouponCodeChangedEvent();

    const String& couponCode() const { return m_couponCode; }

private:
    ApplePayCouponCodeChangedEvent(const AtomString& type, String&&);

    const String m_couponCode;
};

} // namespace WebCore

#endif // ENABLE(APPLE_PAY_COUPON_CODE)
